@@ -13,7 +13,7 @@ Usage::
 """
 import sys
 from datetime import datetime
-from typing import Any, Dict, List, Union
+from typing import Any, Dict, List, Mapping, Sequence, Union
 
 from .literals import (
     AutoTuneDesiredStateType,
@@ -21,6 +21,7 @@ from .literals import (
     DeploymentStatusType,
     DescribePackagesFilterNameType,
     DomainPackageStatusType,
+    EngineTypeType,
     ESPartitionInstanceTypeType,
     ESWarmPartitionInstanceTypeType,
     InboundCrossClusterSearchConnectionStatusCodeType,
@@ -141,6 +142,7 @@ __all__ = (
     "InstanceCountLimitsTypeDef",
     "InstanceLimitsTypeDef",
     "LimitsTypeDef",
+    "ListDomainNamesRequestRequestTypeDef",
     "ListDomainNamesResponseTypeDef",
     "ListDomainsForPackageRequestRequestTypeDef",
     "ListDomainsForPackageResponseTypeDef",
@@ -226,7 +228,7 @@ AddTagsRequestRequestTypeDef = TypedDict(
     "AddTagsRequestRequestTypeDef",
     {
         "ARN": str,
-        "TagList": List["TagTypeDef"],
+        "TagList": Sequence["TagTypeDef"],
     },
 )
 
@@ -314,7 +316,7 @@ AutoTuneOptionsInputTypeDef = TypedDict(
     "AutoTuneOptionsInputTypeDef",
     {
         "DesiredState": AutoTuneDesiredStateType,
-        "MaintenanceSchedules": List["AutoTuneMaintenanceScheduleTypeDef"],
+        "MaintenanceSchedules": Sequence["AutoTuneMaintenanceScheduleTypeDef"],
     },
     total=False,
 )
@@ -447,12 +449,12 @@ _OptionalCreateElasticsearchDomainRequestRequestTypeDef = TypedDict(
         "CognitoOptions": "CognitoOptionsTypeDef",
         "EncryptionAtRestOptions": "EncryptionAtRestOptionsTypeDef",
         "NodeToNodeEncryptionOptions": "NodeToNodeEncryptionOptionsTypeDef",
-        "AdvancedOptions": Dict[str, str],
-        "LogPublishingOptions": Dict[LogTypeType, "LogPublishingOptionTypeDef"],
+        "AdvancedOptions": Mapping[str, str],
+        "LogPublishingOptions": Mapping[LogTypeType, "LogPublishingOptionTypeDef"],
         "DomainEndpointOptions": "DomainEndpointOptionsTypeDef",
         "AdvancedSecurityOptions": "AdvancedSecurityOptionsInputTypeDef",
         "AutoTuneOptions": "AutoTuneOptionsInputTypeDef",
-        "TagList": List["TagTypeDef"],
+        "TagList": Sequence["TagTypeDef"],
     },
     total=False,
 )
@@ -650,7 +652,7 @@ DescribeElasticsearchDomainResponseTypeDef = TypedDict(
 DescribeElasticsearchDomainsRequestRequestTypeDef = TypedDict(
     "DescribeElasticsearchDomainsRequestRequestTypeDef",
     {
-        "DomainNames": List[str],
+        "DomainNames": Sequence[str],
     },
 )
 
@@ -696,7 +698,7 @@ DescribeElasticsearchInstanceTypeLimitsResponseTypeDef = TypedDict(
 DescribeInboundCrossClusterSearchConnectionsRequestRequestTypeDef = TypedDict(
     "DescribeInboundCrossClusterSearchConnectionsRequestRequestTypeDef",
     {
-        "Filters": List["FilterTypeDef"],
+        "Filters": Sequence["FilterTypeDef"],
         "MaxResults": int,
         "NextToken": str,
     },
@@ -715,7 +717,7 @@ DescribeInboundCrossClusterSearchConnectionsResponseTypeDef = TypedDict(
 DescribeOutboundCrossClusterSearchConnectionsRequestRequestTypeDef = TypedDict(
     "DescribeOutboundCrossClusterSearchConnectionsRequestRequestTypeDef",
     {
-        "Filters": List["FilterTypeDef"],
+        "Filters": Sequence["FilterTypeDef"],
         "MaxResults": int,
         "NextToken": str,
     },
@@ -735,7 +737,7 @@ DescribePackagesFilterTypeDef = TypedDict(
     "DescribePackagesFilterTypeDef",
     {
         "Name": DescribePackagesFilterNameType,
-        "Value": List[str],
+        "Value": Sequence[str],
     },
     total=False,
 )
@@ -743,7 +745,7 @@ DescribePackagesFilterTypeDef = TypedDict(
 DescribePackagesRequestRequestTypeDef = TypedDict(
     "DescribePackagesRequestRequestTypeDef",
     {
-        "Filters": List["DescribePackagesFilterTypeDef"],
+        "Filters": Sequence["DescribePackagesFilterTypeDef"],
         "MaxResults": int,
         "NextToken": str,
     },
@@ -839,6 +841,7 @@ DomainInfoTypeDef = TypedDict(
     "DomainInfoTypeDef",
     {
         "DomainName": str,
+        "EngineType": EngineTypeType,
     },
     total=False,
 )
@@ -1037,7 +1040,7 @@ FilterTypeDef = TypedDict(
     "FilterTypeDef",
     {
         "Name": str,
-        "Values": List[str],
+        "Values": Sequence[str],
     },
     total=False,
 )
@@ -1186,6 +1189,14 @@ LimitsTypeDef = TypedDict(
     total=False,
 )
 
+ListDomainNamesRequestRequestTypeDef = TypedDict(
+    "ListDomainNamesRequestRequestTypeDef",
+    {
+        "EngineType": EngineTypeType,
+    },
+    total=False,
+)
+
 ListDomainNamesResponseTypeDef = TypedDict(
     "ListDomainNamesResponseTypeDef",
     {
@@ -1516,7 +1527,7 @@ RemoveTagsRequestRequestTypeDef = TypedDict(
     "RemoveTagsRequestRequestTypeDef",
     {
         "ARN": str,
-        "TagKeys": List[str],
+        "TagKeys": Sequence[str],
     },
 )
 
@@ -1698,9 +1709,9 @@ _OptionalUpdateElasticsearchDomainConfigRequestRequestTypeDef = TypedDict(
         "SnapshotOptions": "SnapshotOptionsTypeDef",
         "VPCOptions": "VPCOptionsTypeDef",
         "CognitoOptions": "CognitoOptionsTypeDef",
-        "AdvancedOptions": Dict[str, str],
+        "AdvancedOptions": Mapping[str, str],
         "AccessPolicies": str,
-        "LogPublishingOptions": Dict[LogTypeType, "LogPublishingOptionTypeDef"],
+        "LogPublishingOptions": Mapping[LogTypeType, "LogPublishingOptionTypeDef"],
         "DomainEndpointOptions": "DomainEndpointOptionsTypeDef",
         "AdvancedSecurityOptions": "AdvancedSecurityOptionsInputTypeDef",
         "NodeToNodeEncryptionOptions": "NodeToNodeEncryptionOptionsTypeDef",
@@ -1834,8 +1845,8 @@ VPCDerivedInfoTypeDef = TypedDict(
 VPCOptionsTypeDef = TypedDict(
     "VPCOptionsTypeDef",
     {
-        "SubnetIds": List[str],
-        "SecurityGroupIds": List[str],
+        "SubnetIds": Sequence[str],
+        "SecurityGroupIds": Sequence[str],
     },
     total=False,
 )
